@@ -1,4 +1,4 @@
-/* $Id: thunar-vfs-io-jobs.c 25750 2007-05-23 21:30:42Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -328,8 +328,8 @@ retry_chown:
       if (g_stat (absolute_path, &statb) == 0)
         {
           /* determine the new uid/gid */
-          nuid = (uid < 0) ? statb.st_uid : uid;
-          ngid = (gid < 0) ? statb.st_gid : gid;
+          nuid = (uid < 0) ? (gint) statb.st_uid : uid;
+          ngid = (gid < 0) ? (gint) statb.st_gid : gid;
 
           /* try to apply the new ownership */
           if (chown (absolute_path, nuid, ngid) < 0)
