@@ -1,6 +1,6 @@
-/* $Id: thunar-vfs-volume.c 24507 2007-01-16 14:40:46Z benny $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -244,6 +244,24 @@ thunar_vfs_volume_is_disc (ThunarVfsVolume *volume)
 
 
 
+/**
+ * thunar_vfs_volume_is_mountable:
+ * @volume : a #ThunarVfsVolume instance.
+ *
+ * Determines whether @volume has a valid filesystem and
+ * if it can be mounted.
+ *
+ * Return value: %TRUE if @volume is mountable, else %FALSE.
+ **/
+gboolean
+thunar_vfs_volume_is_mountable (ThunarVfsVolume *volume)
+{
+  g_return_val_if_fail (THUNAR_VFS_IS_VOLUME (volume), FALSE);
+  return (*THUNAR_VFS_VOLUME_GET_CLASS (volume)->get_status) (volume) & THUNAR_VFS_VOLUME_STATUS_MOUNTABLE;
+}
+
+
+
 /**
  * thunar_vfs_volume_is_mounted:
  * @volume : a #ThunarVfsVolume instance.
@@ -296,9 +314,7 @@ gboolean
 thunar_vfs_volume_is_ejectable (ThunarVfsVolume *volume)
 {
   g_return_val_if_fail (THUNAR_VFS_IS_VOLUME (volume), FALSE);
-
-  /* we can only eject removable media, that are present (surprise, surprise) */
-  return (thunar_vfs_volume_is_present (volume) && thunar_vfs_volume_is_removable (volume));
+  return (*THUNAR_VFS_VOLUME_GET_CLASS (volume)->is_ejectable) (volume);
 }
 
 
